@@ -1,15 +1,29 @@
 #' Species parameters
 #' 
-#' These functions allow you to get or set the species parameters stored in
-#' a MizerParams object.
+#' These functions allow you to get or set the species-specific parameters
+#' stored in a MizerParams object.
+#'
 #' 
-#' The `species_params` data frame holds species-specific parameters. The data
-#' frame has one row for each species and one column for each species parameter.
 #' There are a lot of species parameters and we will list them all below, but
 #' most of them have sensible default values. The only required columns are
 #' `species` for the species name and `w_max` for its maximum size. However
 #' if you have information about the values of other parameters then you should
-#' include them in the `species_params` data frame.
+#' provide them.
+#' 
+#' Mizer distinguishes between the species parameters that you have given
+#' explicitly and the species parameters that have been calculated by mizer or
+#' set to default values. You can retrieve the given species parameters with
+#' `given_species_params()` and the calculated ones with
+#' `calculated_species_params()`. You get all species_params with
+#' `species_params()`.
+#' 
+#' If you change given species parameters with `given_species_params<-()` this
+#' will trigger a re-calculation of the calculated species parameters, where
+#' necessary. However if you change species parameters with `species_params<-()`
+#' no recalculation will take place and furthermore your values could be
+#' overwritten by a future recalculation triggered by a call to
+#' `given_species_params<-()` . So in most use cases you will only want to use
+#' `given_species_params<-()`.
 #' 
 #' There are some species parameters that are used to set up the
 #' size-dependent parameters that are used in the mizer model:
@@ -28,8 +42,8 @@
 #'   [lognormal_pred_kernel()]. There will be other parameters if you are 
 #'   using other predation kernel functions.
 #'   
-#' When you change one of the above species parameters in an already existing
-#' MizerParams object using [species_params<-()], the new value will be
+#' When you change one of the above species parameters using 
+#' `given_species_params<-()` or `species_params<-()`, the new value will be
 #' used to update the corresponding size-dependent rates automatically, unless
 #' you have set those size-dependent rates manually, in which case the
 #' corresponding species parameters will be ignored.
@@ -57,14 +71,12 @@
 #' * `a` and `b` are the parameters in the allometric weight-length
 #'   relationship \eqn{w = a l ^ b}.
 #'   
-#' If you have supplied these, then you can replace weight parameters
-#' like `w_max`, `w_mat`, `w_mat25` and `w_min` by their corresponding length
-#' parameters `l_max`, `l_mat`, `l_mat25` and `l_min`.
+#' If you have supplied the `a` and `b` parameters, then you can replace weight
+#' parameters like `w_max`, `w_mat`, `w_mat25` and `w_min` by their
+#' corresponding length parameters `l_max`, `l_mat`, `l_mat25` and `l_min`.
 #'   
-#' Not all species parameters have to be specified by the user. If they are
-#' missing, [newMultispeciesParams()] will give them default values, sometimes
-#' by using other species parameters. The parameters that are only used to
-#' calculate default values for other parameters are:
+#' The parameters that are only used to calculate default values for other
+#' parameters are:
 #' 
 #' * `f0` is the feeding level and is used to get a default value for the
 #'   coefficient of the search volume `gamma`, see [get_gamma_default()].
@@ -74,11 +86,9 @@
 #' * `age_mat` is the age at maturity and is used to get a default value for
 #'   the coefficient `h` of the maximum intake rate, see [get_h_default()].
 #'   
-#' Note that these parameters are ignored if the parameters for which they allow
-#' defaults to be calculated have instead been set explicitly. Also, these
-#' parameters will only be used when setting up a new model with 
-#' [newMultispeciesParams()]. Changing them later will have no effect 
-#' because the default for the other parameters will not be recalculated.
+#' Note that setting these parameters with `species_params<-()` will have no
+#' effect. You need to set them with `given_species_params<-()` in order to
+#' trigger a re-calculation of the other species parameters.
 #' 
 #' In the past mizer also used the von Bertalanffy parameters `k_vb`, `w_inf`
 #' and `t0` to determine a default for `h`. This is unreliable and is therefore
@@ -104,21 +114,22 @@
 #' Other species-specific information that is related to how the species is
 #' fished is specified in a gear parameter data frame, see [gear_params()].
 #' However in the case where each species is caught by only a single gear, 
-#' this information can also optionally be provided as columns in the
-#' `species_params` data frame and [newMultispeciesParams()] will transfer
-#' them to the `gear_params` data frame. However changing these parameters later
-#' in the species parameter data frame will have no effect.
+#' this information can also optionally be provided as species parameters and
+#' [newMultispeciesParams()] will transfer them to the `gear_params` data frame.
+#' However changing these parameters later in the species parameter data frames
+#' will have no effect.
 #' 
-#' You are allowed to include additional columns in the `species_params`
-#' data frame. They will simply be ignored by mizer but will be stored in the
+#' You are allowed to include additional columns in the species parameter
+#' data frames. They will simply be ignored by mizer but will be stored in the
 #' MizerParams object, in case your own code makes use of them.
 #' 
 #' @param params A MizerParams object
 #' @return Data frame of species parameters
 #' @export
-#' @seealso [validSpeciesParams()]
+#' @seealso [validSpeciesParams()], [completeSpeciesParams()]
 #' @family functions for setting parameters
 species_params <- function(params) {
+    assert_that(is(params, "MizerParams"))
     params@species_params
 }
 
@@ -126,12 +137,94 @@ species_params <- function(params) {
 #' @param value A data frame with the species parameters
 #' @export
 `species_params<-` <- function(params, value) {
-    value <- validSpeciesParams(value)
+    assert_that(is(params, "MizerParams"))
+    value <- completeSpeciesParams(value)
     params@species_params <- value
     suppressMessages(setParams(params))
 }
 
 
+#' @rdname species_params
+#' @export
+given_species_params <- function(params) {
+    assert_that(is(params, "MizerParams"))
+    params@given_species_params
+}
+
+#' @rdname species_params
+#' @export
+`given_species_params<-` <- function(params, value) {
+    assert_that(is(params, "MizerParams"))
+    value <- validSpeciesParams(value)
+    old_value <- params@given_species_params
+    
+    # Create data frame which contains only the values that have changed 
+    common_columns <- intersect(names(value), names(params@given_species_params))
+    new_columns <- setdiff(names(value), names(params@given_species_params))
+    changes <- value[common_columns]
+    changes[changes == params@given_species_params[common_columns]] <- NA
+    # Remove columns that only contain NAs
+    changes <- changes %>% select(where(~ !all(is.na(.))))
+    # Add new columns
+    changes <- cbind(changes, value[new_columns])
+    
+    # Give warnings when values are changed that will have no impact
+    if ("gamma" %in% names(params@given_species_params) &
+        "f0" %in% names(changes) &
+        any(!is.na(params@given_species_params$gamma[!is.na(changes$f0)]))) {
+        warning("You have specified some values for `f0` that are going to be ignored because values for `gamma` have already been given.")
+    }
+    if ("ks" %in% names(params@given_species_params) &
+        "fc" %in% names(changes) &
+        any(!is.na(params@given_species_params$ks[!is.na(changes$fc)]))) {
+        warning("You have specified some values for `fc` that are going to be ignored because values for `ks` have already been given.")
+    }
+    if ("h" %in% names(params@given_species_params) &
+        "age_mat" %in% names(changes) &
+        any(!is.na(params@given_species_params$h[!is.na(changes$age_mat)]))) {
+        warning("You have specified some values for `age_mat` that are going to be ignored because values for `h` have already been given.")
+    }
+    
+    # Warn when user tries to change gear parameters
+    if (any(c("catchability", "selectivity", "l50", "l25", "sel_func") %in% 
+            names(changes))) {
+        warning("To make changes to gears you should use `gear_params()<-`, not `species_params()`.")
+    }
+    if ("yield_observed" %in% names(changes)) {
+        warning("To change the observed yield you should use `gear_params()<-`, not `species_params()`.")
+    }
+    
+    params@given_species_params <- value
+    params@species_params <- completeSpeciesParams(value)
+    suppressMessages(setParams(params))
+}
+
+#' @rdname species_params
+#' @export
+calculated_species_params <- function(params) {
+    assert_that(is(params, "MizerParams"))
+    # Identifying common columns
+    common_cols <- intersect(names(params@species_params), 
+                             names(params@given_species_params))
+    # Copy df1 to new_df
+    calculated <- params@species_params
+    # remove the entries that are also in given_species_params
+    for (col in common_cols) {
+        calculated[[col]] <- replace_with_na(calculated[[col]], 
+                                             params@given_species_params[[col]])
+    }
+    # Removing columns that only contain NAs
+    calculated <- calculated %>%
+        select(where(~ !all(is.na(.))))
+    
+    return(calculated)
+}
+
+# Function to replace overlapping entries with NA
+replace_with_na <- function(x, y) {
+    ifelse(is.na(y), x, NA)
+}
+
 #' Set a species parameter to a default value
 #'
 #' If the species parameter does not yet exist in the species parameter data
@@ -195,7 +288,11 @@ set_species_param_default <- function(object, parname, default,
 #' If `age_mat` is missing in the species parameter data frame, then it is
 #' calculated from the von Bertalanffy growth curve parameters `k_vb` and
 #' (optionally `t0`) taken from the species parameter data frame. This is not
-#' reliable and a warning is issued.
+#' reliable and a warning is issued. 
+#' 
+#' If no growth information is given at all for a species, the default is set
+#' to `h = 30`.
+#' 
 #' @param params A MizerParams object or a species parameter data frame
 #' @return A vector with the values of h for all species
 #' @export
@@ -206,15 +303,16 @@ get_h_default <- function(params) {
     if (is(params, "MizerParams")) {
         species_params <- params@species_params
     } else {
-        species_params <- validSpeciesParams(params)
+        species_params <- completeSpeciesParams(params)
     }
+    assert_that("n" %in% names(species_params))
     species_params <- set_species_param_default(species_params, "f0", 0.6)
     if (!("h" %in% colnames(species_params))) {
         species_params[["h"]] <- rep(NA, nrow(species_params))
     }
     missing <- is.na(species_params[["h"]])
     if (any(missing)) {
-        # The following should be assured by `validSpeciesParams()`
+        # The following should be assured by `completeSpeciesParams()`
         assert_that(is.numeric(species_params$f0),
                     noNA(species_params$alpha),
                     "alpha" %in% names(species_params))
@@ -227,7 +325,6 @@ get_h_default <- function(params) {
         }
         species_params <- species_params %>% 
             set_species_param_default("fc", 0.2) %>% 
-            set_species_param_default("n", 3 / 4) %>% 
             set_species_param_default(
                 "age_mat", age_mat_vB(species_params),
                 strwrap("Because the age at maturity is not known, I need to 
@@ -241,10 +338,15 @@ get_h_default <- function(params) {
         h <- (w_mat^(1 - n) - w_min^(1 - n)) / age_mat / (1 - n) / 
             species_params$alpha / (species_params$f0 - species_params$fc)
         
-        if (any(is.na(h[missing])) || any(h[missing] <= 0)) {
-            stop("Could not calculate h.")
-        }
         species_params[missing, "h"] <- h[missing]
+        
+        # If no acceptable default could be calculated, set h=30
+        missing <- is.na(species_params[["h"]]) | species_params[["h"]] <= 0
+        if (any(missing)) {
+            signal("For species where no growth information is available the parameter h has been set to h = 30.",
+                   class = "info_about_default", var = "h", level = 3)
+            species_params[missing, "h"] <- 30
+        }
     }
     return(species_params[["h"]])
 }
@@ -371,7 +473,9 @@ get_f0_default <- function(params) {
 #' @concept helper
 #' @family functions calculating defaults
 get_ks_default <- function(params) {
-    assert_that(is(params, "MizerParams"))
+    assert_that(is(params, "MizerParams"),
+                "n" %in% names(params@species_params),
+                "p" %in% names(params@species_params))
     if (!"h" %in% names(params@species_params) ||
         any(is.na(params@species_params[["h"]]))) {
         params@species_params[["h"]] <- get_h_default(params)
@@ -381,19 +485,17 @@ get_ks_default <- function(params) {
     ks_default <- sp$fc * sp$alpha * sp[["h"]] * sp$w_mat^(sp[["n"]] - sp[["p"]])
     
     message <- ("No ks column so calculating from critical feeding level.")
-    params <- set_species_param_default(params, "ks", ks_default, message)
-    if (any(is.na(params@species_params$ks) | 
-            is.infinite(params@species_params$ks))) {
+    sp <- set_species_param_default(sp, "ks", ks_default, message)
+    if (any(is.na(sp$ks) |  is.infinite(sp$ks))) {
         stop("Could not calculate default values for the missing species ",
-             "parameter ks. Got: ", params@species_params$ks)
+             "parameter ks. Got: ", sp$ks)
     }
-    return(params@species_params$ks)
+    return(sp$ks)
 }
 
 #' Validate species parameter data frame
 #' 
-#' Check validity of species parameters and set defaults for missing but
-#' required parameters.
+#' Check validity of species parameters.
 #' 
 #' @param species_params The user-supplied species parameter data frame
 #' @return A valid species parameter data frame
@@ -411,12 +513,6 @@ get_ks_default <- function(params) {
 #' If a `w_inf` column is given but no `w_max` then the value from `w_inf` is
 #' used. This is for backwards compatibility.
 #' 
-#' The function sets default values if any of the following are missing or NA
-#' * `w_mat` is set to `w_max/4`
-#' * `w_min` is set to `0.001`
-#' * `alpha` is set to `0.6`
-#' * `interaction_resource` is set to `1`
-#' 
 #' Some inconsistencies in the size parameters are resolved as follows:
 #' * Any `w_mat` that is not smaller than `w_max` is set to `w_max / 4`.
 #' * Any `w_mat25` that is not smaller than `w_mat` is set to NA.
@@ -435,7 +531,7 @@ get_ks_default <- function(params) {
 #' to produce a viable model. More checks of the parameters are performed by the
 #' individual rate-setting functions (see [setParams()] for the list of these
 #' functions).
-#' @seealso species_params
+#' @seealso species_params()
 #' @concept helper
 #' @export
 validSpeciesParams <- function(species_params) {
@@ -501,59 +597,94 @@ validSpeciesParams <- function(species_params) {
         stop("`w_max` contains non-numeric values.")
     }
     
-    # Defaults ----
-    sp <- sp %>% 
-        set_species_param_default("w_mat", sp$w_max / 4) %>% 
-        set_species_param_default("w_min", 0.001) %>% 
-        set_species_param_default("alpha", 0.6) %>% 
-        set_species_param_default("interaction_resource", 1)
-    
     # check w_mat ----
-    wrong <- sp$w_mat >= sp$w_max
-    if (any(wrong)) {
-        message("For the species ", 
-                paste(sp$species[wrong], collapse = ", "),
-                " the value for `w_mat` is not smaller than that of `w_max`.",
-                " I have corrected that by setting it to about 25% of `w_mat.")
-        sp$w_mat[wrong] <- sp$w_max[wrong] / 4
+    if ("w_mat" %in% names(sp)) {
+        wrong <- !is.na(sp$w_mat) & sp$w_mat >= sp$w_max
+        if (any(wrong)) {
+            warning("For the species ", 
+                    paste(sp$species[wrong], collapse = ", "),
+                    " the value for `w_mat` is not smaller than that of `w_max`.",
+                    " I have corrected that by setting it to 25% of `w_max.")
+            sp$w_mat[wrong] <- sp$w_max[wrong] / 4
+        }
+        
+        # check w_mat25 ----
+        if ("w_mat25" %in% names(sp)) {
+            wrong <- !is.na(sp$w_mat) & !is.na(sp$w_mat25) & sp$w_mat25 >= sp$w_mat
+            if (any(wrong)) {
+                warning("For the species ", 
+                        paste(sp$species[wrong], collapse = ", "),
+                        " the value for `w_mat25` is not smaller than that of `w_mat`.",
+                        " I have corrected that by setting it to NA.")
+                sp$w_mat25[wrong] <- NA
+            }
+        }
+        
+        # check w_min ----
+        if ("w_min" %in% names(sp)) {
+            wrong <- !is.na(sp$w_min) & !is.na(sp$w_mat) & sp$w_min >= sp$w_mat
+            if (any(wrong)) {
+                sp$w_min[wrong] <- pmin(0.001, sp$w_mat[wrong] / 10)
+                warning("For the species ", 
+                        paste(sp$species[wrong], collapse = ", "),
+                        " the value for `w_min` is not smaller than that of `w_mat`.",
+                        " I have reduced the values.")
+            }
+        }
     }
-    
-    # check w_mat25 ----
-    # For w_mat25 it is o.k. if it is NA, but if given it must be 
-    #  smaller than w_mat
-    wrong <- !is.na(sp$w_mat25) & sp$w_mat25 >= sp$w_mat
-    if (any(wrong)) {
-        message("For the species ", 
-                paste(sp$species[wrong], collapse = ", "),
-                " the value for `w_mat25` is not smaller than that of `w_mat`.",
-                " I have corrected that by setting it to NA.")
-        sp$w_mat25[wrong] <- NA
-    }
-    
-    # check w_min ----
-    wrong <- sp$w_min >= sp$w_mat
-    if (any(wrong)) {
-        sp$w_min[wrong] <- pmin(0.001, sp$w_mat[wrong] / 10)
-        message("For the species ", 
-                paste(sp$species[wrong], collapse = ", "),
-                " the value for `w_min` is not smaller than that of `w_mat`.",
-                " I have reduced the values.")
-    }
-    
     sp
 }
 
+#' Complete species parameter data frame with default values
+#' 
+#' Sets defaults for missing but required species parameters.
+#' 
+#' @param species_params The user-supplied species parameter data frame
+#' @return A completed species parameter data frame
+#' 
+#' The function sets default values if any of the following species parameters
+#' are missing or NA:
+#' * `w_mat` is set to `w_max/4`
+#' * `w_min` is set to `0.001`
+#' * `alpha` is set to `0.6`
+#' * `interaction_resource` is set to `1`
+#' * `n` is set to `3/4`
+#' 
+#' It calls [validSpeciesParams()] to check the validity of the species
+#' parameters. Nevertheless the species parameters returned by this function are not guaranteed
+#' to produce a viable model. More checks of the parameters are performed by the
+#' individual rate-setting functions (see [setParams()] for the list of these
+#' functions).
+#' @seealso [species_params()], [validSpeciesParams()]
+#' @concept helper
+#' @export
+completeSpeciesParams <- function(species_params) {
+    sp <- validSpeciesParams(species_params)
+    sp <- set_species_param_default(sp, "w_mat", sp$w_max / 4)
+    sp <- set_species_param_default(sp, "w_min", 0.001)
+    sp <- set_species_param_default(sp, "alpha", 0.6)
+    sp <- set_species_param_default(sp, "interaction_resource", 1)
+    sp <- set_species_param_default(sp, "n", 3/4)
+    validSpeciesParams(sp)
+}
+
 # Set weight-based parameter from length-based parameter
 set_species_param_from_length <- function(sp, pw, pl) {
     if (pl %in% names(sp)) {
         vw <- l2w(sp[[pl]], sp)
+        if (any(vw <= 0, na.rm = TRUE)) {
+            stop("All lengths should be positive and non-zero.")
+        }
         sp <- set_species_param_default(sp, pw, vw)
+        # If both weight and length are given, check that they agree to
+        # within 10% at least.
         incons <- !is.na(sp[[pw]]) & !is.na(sp[[pl]]) &
-            sp[[pw]] != vw
+            (abs(sp[[pw]] - vw) / pmax(sp[[pw]], vw) > 0.1)
         if (any(incons)) {
-            warning("For the following species your value for ", pw,
-                    " and your value for ", pl, " are not consistent: ",
-                    paste(sp$species[incons], collapse = ", "))
+            signal(paste0("For the following species I will ignore your value for ",
+                         pl, " because it is not consistent with your value for ",
+                         pw, ": ", paste(sp$species[incons], collapse = ", ")),
+                   class = "info_about_default", var = pl, level = 3)
         }
     }
     sp
